#include "main.h"
#include "stm32f7xx_hal.h"
#include "usb_device.h"
#include "stm32f767Nucleo.h"
#include "demo.h"

#include "FreeRTOS.h"
#include "task.h"
#include "semphr.h"

#define STARTTASK_PRIO 5
#define STARTTASK_DELAY 100
#define STARTTASK_STACKSIZE 128

#define LEDTASK1_PRIO 3
#define LEDTASK1_DELAY 1000
#define LEDTASK1_STACKSIZE 128

#define LEDTASK2_PRIO 4
#define LEDTASK2_DELAY 55
#define LEDTASK2_STACKSIZE 128

TIM_HandleTypeDef htim7;
UART_HandleTypeDef huart3;

static void StartTask(void *pvParameters );
static void LEDblink1(void *pvParameters );
static void LEDblink2(void *pvParameters );

SemaphoreHandle_t  LEDMutex;

#ifdef TRC_USE_TRACEALYZER_RECORDER
traceString LED1Chn;
#endif

int main(void)
{
  HAL_Init();
  SystemClock_Config();
  MX_GPIO_Init();
  MX_USART3_UART_Init();
  MX_TIM7_Init();
   
#ifdef TRC_USE_TRACEALYZER_RECORDER
#if (TRC_CFG_RECORDER_MODE == TRC_RECORDER_MODE_SNAPSHOT)
    vTraceEnable(TRC_START);
#else
    vTraceEnable(TRC_INIT);//vTraceEnable(TRC_INIT);
#endif
#endif
    
    LEDMutex = xSemaphoreCreateMutex();
    
#if (TRC_USE_TRACEALYZER_RECORDER == 1)
    vTraceSetSemaphoreName(LEDMutex,"LED_Mutex");
    LED1Chn = xTraceRegisterString("LED1Status");
#endif

    xTaskCreate( StartTask, "Init", STARTTASK_STACKSIZE, NULL, STARTTASK_PRIO, NULL );
    vStartDemoApplication();
    vTaskStartScheduler();
    while (1){
    }
}

static void StartTask(void *pvParameters )
{
    ( void ) pvParameters;
    for(int n=0; n<10; n++)
    {
        LEDTOGGLE(LED3);
        vTaskDelay(STARTTASK_DELAY);
    }
    MX_USB_DEVICE_Init();
    
    xTaskCreate( LEDblink1, "LED1", LEDTASK1_STACKSIZE, NULL, LEDTASK1_PRIO, NULL );
    xTaskCreate( LEDblink2, "LED2", LEDTASK2_STACKSIZE, NULL, LEDTASK2_PRIO, NULL );
    vTaskDelete(NULL);
}

void StartDefaultTask(void const * argument)
{
    

}

static void LEDblink1(void *pvParameters )
{
    /* Remove compiler warning about unused parameter. */
    ( void ) pvParameters;
    while(1)
    {
        xSemaphoreTake(LEDMutex,portMAX_DELAY );
        LEDON(LED1);
#if (TRC_USE_TRACEALYZER_RECORDER == 1)
        vTracePrintF(LED1Chn, "LED:%d",1);
#endif
        vTaskDelay(LEDTASK1_DELAY);
        LEDOFF(LED1);
#if (TRC_USE_TRACEALYZER_RECORDER == 1)
        vTracePrintF(LED1Chn, "LED:%d",0);
#endif
        xSemaphoreGive(LEDMutex);
        vTaskDelay(LEDTASK1_DELAY);
    }
}

static void LEDblink2(void *pvParameters )
{
    /* Remove compiler warning about unused parameter. */
    ( void ) pvParameters;
    while(1)
    {
        xSemaphoreTake(LEDMutex,portMAX_DELAY );
        LEDON(LED1);
#if (TRC_USE_TRACEALYZER_RECORDER == 1)
        vTracePrintF(LED1Chn, "LED:%d",1);
#endif
        vTaskDelay(LEDTASK2_DELAY);
        LEDOFF(LED1);
#if (TRC_USE_TRACEALYZER_RECORDER == 1)
        vTracePrintF(LED1Chn, "LED:%d",0);
#endif
        xSemaphoreGive(LEDMutex);
        vTaskDelay(LEDTASK2_DELAY);
    }
}

void HAL_GPIO_EXTI_Callback(uint16_t input)
{
    if(input==USER_Btn_Pin)
    {
        LEDTOGGLE(LED2);
    }
}
